@@ -6,7 +6,7 @@
 #' @param data.train Training data with the same columns as \code{data}, except for an additional column specifying cause-of-death label. It is not used if \code{data.type} is ``WHO'' and \code{model} is ``InterVA'' or ``InSilicoVA''.  The first column also has to be death ID for ``WHO'' and ``customized'' types.
 #' @param causes.train the column name of the cause-of-death assignment label in training data.
 #' @param causes.table list of causes to consider in the training data. Default to be NULL, which uses all the causes present in the training data.
-#' @param model Currently support three models: ``InSilicoVA'', ``InterVA'', and ``Tariff''.
+#' @param model Currently support four models: ``InSilicoVA'', ``InterVA'', ``Tariff'', and ``NBC''.
 #' @param Nchain Parameter specific to ``InSilicoVA'' model. Currently not used.
 #' @param Nsim Parameter specific to ``InSilicoVA'' model. Number of iterations to run the sampler.
 #' @param version Parameter specific to ``InterVA'' model. Currently supports ``4.02'', and ``4.03''. ``4.03'' is strongly recommended as it fixes several major bugs in ``4.02'' version. ``4.02'' is only included for backward compatibility.
@@ -17,11 +17,11 @@
 #' \itemize{
 #' \item{\code{quantile}: }{the rankings of the P(S|C) are obtained by matching the same quantile distributions in the default InterVA P(S|C)}\item{\code{fixed}: }{P(S|C) are matched to the closest values in the default InterVA P(S|C) table.} \item{\code{empirical}: }{no ranking is calculated, but use the empirical conditional probabilities directly, which will force \code{updateCondProb} to be FALSE for InSilicoVA algorithm.}  
 #'}
-#' @param ... other arguments passed to \code{\link[InSilicoVA]{insilico}}, \code{\link[InterVA4]{InterVA}}, \code{\link{interVA.train}}, and \code{\link[Tariff]{tariff}}. See respective package documents for details. 
+#' @param ... other arguments passed to \code{\link[InSilicoVA]{insilico}}, \code{\link[InterVA4]{InterVA}}, \code{\link{interVA.train}}, \code{\link[Tariff]{tariff}}, and \code{\link[nbc4va]{nbc}}. See respective package documents for details. 
 #'
 #' @return a fitted object
 #' @export codeVA
-#' @seealso \code{\link[InSilicoVA]{insilico}}, \code{\link[InterVA4]{InterVA}}, \code{\link{interVA.train}}, and \code{\link[Tariff]{tariff}}
+#' @seealso \code{\link[InSilicoVA]{insilico}}, \code{\link[InterVA4]{InterVA}}, \code{\link{interVA.train}}, \code{\link[Tariff]{tariff}}, and \code{\link[nbc4va]{nbc}}.
 #' @importFrom InSilicoVA insilico insilico.train 
 #' @importFrom InterVA4 InterVA CSMF
 #' @importFrom Tariff tariff
@@ -32,7 +32,8 @@
 #' @references James, S. L., Flaxman, A. D., Murray, C. J., & Population Health Metrics Research Consortium. (2011). \emph{Performance of the Tariff Method: validation of a simple additive algorithm for analysis of verbal autopsies.} \emph{Population Health Metrics, 9(1), 1-16.}
 #' @references Zehang R. Li, Tyler H. McCormick, Samuel J. Clark (2014) \emph{InterVA4: An R package to analyze verbal autopsy data.} \emph{Center for Statistics and the Social Sciences Working Paper, No.146}
 #' @references http://www.interva.net/
-#' @keywords InSilicoVA InterVA4 Tariff
+#' @references Miasnikof P, Giannakeas V, Gomes M, Aleksandrowicz L, Shestopaloff AY, Alam D, Tollman S, Samarikhalaj, Jha P. \emph{Naive Bayes classifiers for verbal autopsies: comparison to physician-based classification for 21,000 child and adult deaths.} \emph{BMC Medicine. 2015;13:286.} 
+#' @keywords InSilicoVA InterVA4 Tariff NBC4VA
 
 #' @examples
 #' \donttest{
@@ -50,13 +51,18 @@
 #' fit3 <- codeVA(data = test, data.type = "customize", model = "Tariff",
 #'                data.train = train, causes.train = "cause", 
 #'                nboot.sig = 100)
+#'
+#' fit4 <- codeVA(data = test, data.type = "customize", model = "NBC",
+#'                data.train = train, causes.train = "cause", known.nbc = TRUE)
+#'
 #' }
 
+
 codeVA <- function(data, data.type = c("WHO", "PHMRC", "customize")[1], 
                   data.train = NULL, 
                   causes.train = NULL, 
                   causes.table = NULL,
-                  model = c("InSilicoVA", "InterVA", "Tariff")[1],
+                  model = c("InSilicoVA", "InterVA", "Tariff", "NBC")[1],
                   Nchain = 1, Nsim=10000, 
                   version = "4.02", HIV = "h", Malaria = "h", 
                   phmrc.type = c("adult", "child", "neonate")[1], 
@@ -69,9 +75,10 @@ codeVA <- function(data, data.type = c("WHO", "PHMRC", "customize")[1],
   # check data input 
   # --------------------------------------------------------------------#
  
-  if(data.type == "WHO" && model == "Tariff"){
+  if(data.type == "WHO" && 
+     (model == "Tariff" || model == "NBC")) {
     if(is.null(data.train) || is.null(causes.train)){
-      stop("Error: need training data for WHO questionnaire input with Tariff method.")
+      stop("Error: need training data for WHO questionnaire input with Tariff or NBC method.")
     }
   }
   if(data.type == "customize"){
@@ -180,10 +187,51 @@ codeVA <- function(data, data.type = c("WHO", "PHMRC", "customize")[1],
     }else{
       stop("Error: unknown data type specified")
     }
+
+  # --------------------------------------------------------------------#
+  #                          NBC 
+  # --------------------------------------------------------------------#
+  }else if(model == "NBC"){
+    #  # make sure the second column is cause     
+    # if(which(colnames(data.train) == causes.train) != 2){
+    #   k <- which(colnames(data.train) == causes.train)
+    #   rest <- (1:dim(data.train)[2])[-c(1, k)]
+    #   data.train <- data.train[, c(1, k, rest)]
+    # }
+    
+    # # make sure the second column is cause     
+    # if(causes.train %in% colnames(data) == FALSE){
+    #   # it is handled
+    # }else if(which(colnames(data) == causes.train) != 2){
+    #   k <- which(colnames(data) == causes.train)
+    #   rest <- (1:dim(data)[2])[-c(1, k)]
+    #   data <- data[, c(1, k, rest)]
+    # }
+
+    # data.train[data.train == "Y"] <- 1
+    # data.train[data.train == ""] <- 0    
+    # data.train[data.train == "."] <- 0
+    # data[data == "Y"] <- 1
+    # data[data == ""] <- 0    
+    # data[data == "."] <- 0
+    # for(i in 3:dim(data.train)[2]){
+    #   data.train[, i] <- as.numeric(data.train[, i])
+    # }
+    # for(i in 2:dim(data)[2]){
+    #   if(colnames(data)[i] != causes.train) data[, i] <- as.numeric(data[, i])
+    # }
+    data.train[, 1] <- as.character(data.train[, 1])
+    data[, 1] <- as.character(data[, 1])
+    # fit <- nbc(train = data.train, 
+    #            test = data, 
+    #            known = known.nbc)
+
+    # update with NBC's official wrapper function
+    fit <- ova2nbc(data.train, data, causes.train)
   }else{
-    stop("Error, unknown model specification")
+        stop("Error, unknown model specification")
   }
-  
+
   return(fit)
 }
 
@@ -194,7 +242,7 @@ codeVA <- function(data, data.type = c("WHO", "PHMRC", "customize")[1],
 #' @param top number of top causes to plot
 #' @param title title of the plot
 #' @param ... additional arguments passed to \code{\link[InSilicoVA]{plot.insilico}}, 
-#' \code{\link[Tariff]{plot.tariff}}, or \code{\link[InterVA4]{CSMF}}.
+#' \code{\link[Tariff]{plot.tariff}}, \code{\link[InterVA4]{CSMF}}, or \code{\link[nbc4va]{plot.nbc}}.
 #'
 #' @export plotVA
 #' @seealso \code{\link[InSilicoVA]{plot.insilico}}, \code{\link[Tariff]{plot.tariff}}, 
@@ -216,10 +264,13 @@ codeVA <- function(data, data.type = c("WHO", "PHMRC", "customize")[1],
 #'                data.train = train, causes.train = "cause", 
 #'                nboot.sig = 100)
 #'
+#' fit4 <- codeVA(data = test, data.type = "customize", model = "NBC",
+#'                data.train = train, causes.train = "cause", known.nbc = TRUE)
 #'
 #' plotVA(fit1)
 #' plotVA(fit2)
 #' plotVA(fit3)
+#' plotVA(fit4)
 #' }
 plotVA <- function(object, top = 10, title = NULL, ...){
   if(class(object) == "interVA"){
@@ -228,6 +279,8 @@ plotVA <- function(object, top = 10, title = NULL, ...){
     plot(object, top = top, main = title, ...)
   }else if(class(object) == "insilico"){
     plot(object, top = top, title = title, ...)
+  }else if(class(object) == "nbc"){
+    plot(object, top.plot = top, main = title, ...)
   }else{
     stop("Unknown object to plot")
   }
